<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>FilterListByDialog</name>
    <message>
        <location filename="filterlistbydialog.ui" line="14"/>
        <source>Filter List By</source>
        <translation>Filtra la lista per</translation>
    </message>
    <message>
        <location filename="filterlistbydialog.ui" line="31"/>
        <source>OrderByName</source>
        <translation>Ordina per nome</translation>
    </message>
    <message>
        <location filename="filterlistbydialog.ui" line="36"/>
        <source>OrderByGenre</source>
        <translation>Ordina per genere</translation>
    </message>
    <message>
        <location filename="filterlistbydialog.ui" line="41"/>
        <source>OrderByCountry</source>
        <translation>Ordina per paese</translation>
    </message>
    <message>
        <location filename="filterlistbydialog.ui" line="61"/>
        <source>Ok</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LyricsWebView</name>
    <message>
        <location filename="lyricswebview.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="lyricswebview.ui" line="28"/>
        <source>about:blank</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Internet Radio Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="39"/>
        <source>Playing: </source>
        <translation>In esecuzione: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Genre: </source>
        <translation>Genere: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>Location:</source>
        <translation>Posizione: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <source>Bitrate:</source>
        <translation>Bitrate: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="67"/>
        <source>Audio Codec: </source>
        <translation>Codec Audio: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="218"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600; text-decoration: underline;&quot;&gt;Internet Radio Player&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt; font-weight:600; text-decoration: underline;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="258"/>
        <source>Artist:</source>
        <translation>Artista: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.ui" line="540"/>
        <source>Lyrics</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="301"/>
        <source>Title:</source>
        <translation>Titolo: </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="339"/>
        <source>lyrics.com</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="524"/>
        <source>Playing now</source>
        <translation>In esecuzione</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="553"/>
        <source>Stations</source>
        <translation>Stazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>Cronology</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="579"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="590"/>
        <location filename="mainwindow.cpp" line="270"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="595"/>
        <source>About Qt</source>
        <translation>Informazioni su Qt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="600"/>
        <source>ToggleFullscreen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="611"/>
        <source>ClearList</source>
        <translation>Azzera Lista</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="616"/>
        <source>RestoreDefaultList</source>
        <translation>Ripristina Lista di default</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="621"/>
        <source>FilterListByGenre</source>
        <translation>Filtra lista per genere</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="626"/>
        <source>FilterListByCountry</source>
        <translation>Filtra lista per paese</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="631"/>
        <source>OrderByName</source>
        <translation>Ordina per nome</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="641"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="644"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="652"/>
        <source>OrderByGenre</source>
        <translation>Ordina per genere</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="657"/>
        <source>OrderByCountry</source>
        <translation>Ordina per paese</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="662"/>
        <source>AddToFavourites</source>
        <translation>Aggiungi ai preferiti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="665"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="670"/>
        <source>DeleteFromFavourites</source>
        <translation>Rimuovi dai preferiti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="673"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="678"/>
        <source>GetFavouriteList</source>
        <translation>Lista preferiti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="446"/>
        <source>DoNotFilter</source>
        <translation>Nessun filtro</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="636"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="87"/>
        <source>&lt;b&gt;Playing:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;In esecuzione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="113"/>
        <source>&lt;b&gt;Genre:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Genere:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="121"/>
        <source>&lt;b&gt;Bitrate:&lt;/b&gt; %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="129"/>
        <source>&lt;b&gt;Location:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Posizione:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="137"/>
        <source>&lt;b&gt;Audio codec:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Codec audio:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="187"/>
        <source>No lyric found</source>
        <translation>Nessun testo trovato</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="206"/>
        <source>Loading lyrics...</source>
        <translation>Sto cercando il testo...</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <oldsource>&lt;h2&gt;Internet Radio Player 0.0.6&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</oldsource>
        <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Internet Radio Player 0.0.8&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt; {2&gt;?} {0.0.8&lt;?} {2&gt;?} {88@?} {88@?}</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="271"/>
        <source>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
        <translation>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="282"/>
        <location filename="mainwindow.cpp" line="284"/>
        <location filename="mainwindow.cpp" line="286"/>
        <location filename="mainwindow.cpp" line="288"/>
        <source>New Station</source>
        <translation>Nuova stazione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="282"/>
        <location filename="mainwindow.cpp" line="310"/>
        <source>Insert Name: </source>
        <translation>Inserisci nome:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="284"/>
        <location filename="mainwindow.cpp" line="312"/>
        <source>Insert Url: </source>
        <translation>Inserisci Indirizzo:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="286"/>
        <location filename="mainwindow.cpp" line="314"/>
        <source>Insert Genre: </source>
        <translation>Inserisci Genere:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Insert Country: </source>
        <translation>Inserisci il Paese:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="310"/>
        <location filename="mainwindow.cpp" line="312"/>
        <location filename="mainwindow.cpp" line="314"/>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Edit Station</source>
        <translation>Modifica la stazione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="334"/>
        <location filename="mainwindow.cpp" line="467"/>
        <location filename="mainwindow.cpp" line="483"/>
        <source>Internet Radio Widget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="335"/>
        <source>Do you really want to delete the chosen station?</source>
        <translation>Vuoi veramente cancellare la stazione evidenziata?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="447"/>
        <source>FilterList</source>
        <translation>Filtra lista</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="448"/>
        <source>ManageFavourites</source>
        <translation>Gestisci preferiti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="468"/>
        <source>This will clear your stations list.&lt;p&gt;Do you really want to continue?</source>
        <translation>Questo azzererà la tua lista stazioni.&lt;p&gt;Vuoi veramente continuare?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="484"/>
        <source>This will clear your stations list and restore default one.&lt;p&gt;Do you really want to continue?</source>
        <translation>Questo azzererà la tua lista stazioni e ripristinerà quella di default-.&lt;p&gt;Vuoi veramente continuare?</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="53"/>
        <source>Application Icon</source>
        <translation>Icona App</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="144"/>
        <source>Hide when closing</source>
        <translation>Nascondi invece di uscire</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="187"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="34"/>
        <location filename="settingsdialog.cpp" line="41"/>
        <source>Icon changed</source>
        <translation>Icona modificata</translation>
    </message>
</context>
</TS>
